/*********************************************************************

           Software Adoption, Employment Composition 
	   and the Skill Content of Occupations 
	   in Chilean Firms  


This do-file: Runs regression results in Main document and online 
              Supplementary Materials

*********************************************************************/

use "ele_2007_2013.dta", replace

xtset id_firma ano

* Sofware measure, IVs, and control variables
loc X1 = "soft19"
loc Z1 = "uso_comp_reg_ict"
loc Z2 = "celular_reg_ict"
loc W1 = "dtam1-dtam4 ledad_firma export foreign credit_constraint ledad_manager lexper deduc_man2 deduc_man3 lipcf_reg urbano_reg laedu_reg dano* trend_reg* nrocomp_reg_sec"
loc W2 = "dtam1-dtam4 ledad_firma export foreign credit_constraint ledad_manager lexper deduc_man2 deduc_man3 lipcf_reg urbano_reg laedu_reg dano* trend_reg* trend_sec* nrocomp_reg_sec"

* Main results: Tables 5, 6 and 9 in Main document
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 shr_cat1_v1 shr_cat2_v1 shr_cat3_v1 shr_cat4_v1 lempleo_cat1_v2 lempleo_cat2_v2 lempleo_cat3_v2 lempleo_cat4_v2 capacitacion capac_manager capac_manager_ict subcontrato 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremos==1 [w=fe_empresa], fe cl(grupo) first
	}

* OLS results: Tables 4 in online Supplementary Materials
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 shr_cat1_v1 shr_cat2_v1 shr_cat3_v1 shr_cat4_v1 

foreach y of local Y {
	xtivreg2 `y' `X1' `W1' if sample==1 & muestra_extremos==1 [w=fe_empresa], fe rob
	}

* Robustness checks: Table 7 in online Supplementary Materials

* Panel A: Autor & Handel (2013) methodology
loc Y index_abst_v1 index_rout_cog_v1 index_man_v1

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremo==1 [w=fe_empresa], fe cl(grupo)
	}

* Panel B: Using IV based on cell-phones
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z2') if sample==1 & muestra_extremos==1 [w=fe_empresa], fe cl(grupo)
	}

* Panel C: Without weights
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremo==1, fe cl(grupo)
	}

* Panel D: Using the complete sample
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 [w=fe_empresa], fe cl(grupo)
	}

* Panel E: Ignoring panel structure of the sample
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

xtivreg2 index_abst_v1_op2 `W1' (soft19=uso_comp_reg_ict) if sample==1 & muestra_extremos==1 [w=fe_empresa], fe cl(grupo) first
gen aux=1 if e(sample)
egen suma=sum(aux), by(id_firma)
gen muestra_nopanel=1 if suma==2 
drop aux suma

foreach y of local Y {
	ivreg2 `y' `W1' dreg* dsec* (`X1'=`Z1') if sample==1 & muestra_nopanel==1 & muestra_extremos==1 [w=fe_empresa], cl(grupo)
	}

* Panel F: Including sector specific time trends
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W2' (`X1'=`Z1') if sample==1 & muestra_extremos==1 [w=fe_empresa], fe cl(grupo)
	}

* Panel G: Acemoglu & Autor task measures by occupation and sector
loc Y index_abst_sec_v1_op2 index_rout_cog_sec_v1_op2 index_man_sec_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremo==1 [w=fe_empresa], fe cl(grupo)
	}

* Panel H: Drops manufacturing sector 
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremos==1 & sector_aux!=3 [w=fe_empresa], fe cl(grupo)
	}

* Panel I: Drops wholesale & retail trade sector 
loc Y index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremos==1 & sector_aux!=6 [w=fe_empresa], fe cl(grupo)
	}

* Heterogeneity of Impact of Complex Software Adoption: Tables 7 and 8 in Main document

* By firm size
gen empleo_total_aux=empleo_cat1 + empleo_cat2 + empleo_cat3 + empleo_cat4
gen tamano_v2=1 if empleo_total_aux<=5
replace tamano_v2=2 if empleo_total_aux>5 & empleo_total_aux<=10
replace tamano_v2=3 if empleo_total_aux>10 & empleo_total_aux<=20
replace tamano_v2=4 if empleo_total_aux>20 & empleo_total_aux<=50
replace tamano_v2=5 if empleo_total_aux>50 & empleo_total_aux<.
drop empleo_total_aux

gen size07=0 if tamano_v2>=2 & tamano_v2<=5 & ano==2007
replace size07=1 if (tamano_v2==1) & ano==2007
egen min=min(size07), by(id_firma)
replace size07=min if size07==.
drop min 

gen nosize07=1 if size07==0
replace nosize07=0 if size07==1

gen soft19_size=soft19*size07
gen soft19_nosize=soft19*nosize07

gen uso_comp_reg_ict_size=uso_comp_reg_ict*size07
gen uso_comp_reg_ict_nosize=uso_comp_reg_ict*nosize07

loc Y shr_cat1_v1 shr_cat2_v1 shr_cat3_v1 shr_cat4_v1 index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

loc X1 = "soft19_size soft19_nosize"
loc Z1 = "uso_comp_reg_ict_size uso_comp_reg_ict_nosize"
loc W1 = "dtam1-dtam4 ledad_firma export foreign credit_constraint ledad_manager lexper deduc_man2 deduc_man3 lipcf_reg urbano_reg laedu_reg dano* trend_reg* nrocomp_reg_sec"

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremos==1 [w=fe_empresa], fe cl(grupo) 
	}

* By education
gen high=0
replace high=1 if sector_aux==9 | sector_aux==4 

gen nohigh=1 if high==0
replace nohigh=0 if high==1

gen soft19_high=soft19*high
gen soft19_nohigh=soft19*nohigh

gen uso_comp_reg_ict_high=uso_comp_reg_ict*high
gen uso_comp_reg_ict_nohigh=uso_comp_reg_ict*nohigh

loc Y shr_cat1_v1 shr_cat2_v1 shr_cat3_v1 shr_cat4_v1 index_abst_v1_op2 index_rout_cog_v1_op2 index_man_v1_op2 

loc X1 = "soft19_high soft19_nohigh"
loc Z1 = "uso_comp_reg_ict_high uso_comp_reg_ict_nohigh"
loc W1 = "dtam1-dtam4 ledad_firma export foreign credit_constraint ledad_manager lexper deduc_man2 deduc_man3 lipcf_reg urbano_reg laedu_reg dano* trend_reg* nrocomp_reg_sec"

foreach y of local Y {
	xtivreg2 `y' `W1' (`X1'=`Z1') if sample==1 & muestra_extremos==1 [w=fe_empresa], fe cl(grupo) 
	}

